=============
b1tddfp Usage
=============

Examples
--------

.. todo::
    These examples are placeholders, useful, but actual example set here is on 
    the todo.

.. code-block:: python

    import bloxone
    dfp = bloxone.b1tddfp('/Users/marrison/configs/emea.ini')
    response = dfp.get('/dfps')
    response = dfp.get('/dfps', id=dfp_id)

